@@ -1,6 +1,6 @@
 from django.apps import AppConfig
 
 
-class HXRequestsConfig(AppConfig):
+class HxRequestsConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
     name = "hx_requests"
