@@ -1,11 +1,19 @@
-from typing import Dict
+from __future__ import annotations
+
 from urllib.parse import parse_qs, urlparse
 
-from django.http import Http404
+from django.conf import settings
+from django.http import Http404, HttpRequest
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import ensure_csrf_cookie
 
 from hx_requests.hx_registry import HxRequestRegistry
+from hx_requests.security_utils import (
+    app_label_for_object,
+    is_globally_allowed,
+    is_hx_spec_allowed,
+    urlname_from_request,
+)
 from hx_requests.utils import deserialize_kwargs, is_htmx_request
 
 
@@ -17,8 +25,6 @@ class HtmxViewMixin:
     HxRequest.
     """
 
-    hx_requests: Dict = []
-
     def dispatch(self, request, *args, **kwargs):
         # Try to dispatch to the right method; if a method doesn't exist,
         # defer to the error handler. Also defer to the error handler if the
@@ -40,29 +46,64 @@ class HtmxViewMixin:
 
     def get_hx_request(self, request):
         hx_request_name = request.GET.get("hx_request_name")
+        if not hx_request_name:
+            raise Http404("Missing required query param 'hx_request_name' for HTMX request.")
+
         hx_request_class = HxRequestRegistry.get_hx_request(hx_request_name)
         if not hx_request_class:
-            raise Http404(
-                f"No HxRequest found with the name {hx_request_name}. Are you sure it's spelled correctly?"
-            )
+            raise Http404(f"No HxRequest found with the name '{hx_request_name}'.")
+
+        if not self.is_hx_allowed(hx_request_class, request):
+            raise Http404(f"HxRequest '{hx_request_name}' is not allowed here.")
+
         return hx_request_class()
 
     def get_hx_extra_kwargs(self, request):
-        kwargs = {}
+        raw = {}
         for key in request.GET:
-            kwargs[key] = request.GET.get(key)
-
-        return deserialize_kwargs(**kwargs)
+            if key == "hx_request_name":
+                continue
+            raw[key] = request.GET.get(key)
+        return deserialize_kwargs(**raw)
 
     def _setup_hx_request(self, request, *args, **kwargs):
         hx_request = self.get_hx_request(request)
         hx_request.view = self
 
-        if hx_request.use_current_url:
+        if getattr(hx_request, "use_current_url", False):
             request = self._use_current_url(request)
         hx_request._setup_hx_request(request, *args, **kwargs)
         return hx_request
 
+    def is_hx_allowed(self, hx_cls: type, request: HttpRequest) -> bool:
+        """
+        Security check: is this HxRequest allowed to be used in this view?
+        """
+        view_app = app_label_for_object(self)
+        hx_app = app_label_for_object(hx_cls)
+        url_name = urlname_from_request(request)
+        hx_name = hx_cls.name  # name attribute set on the HxRequest class
+
+        # If security controls are disabled, always allow
+        if not getattr(settings, "HX_REQUESTS_ENFORCE_SAME_APP", True):
+            return True
+
+        # Global allow for this HxRequest?
+        global_allow = getattr(settings, "HX_REQUESTS_GLOBAL_ALLOW", []) or []
+        if is_globally_allowed(global_allow, hx_app, hx_name):
+            return True
+
+        # Class-level allow spec
+        allowed_spec = getattr(hx_cls, "allowed", None)
+        additive = bool(getattr(hx_cls, "allow_additive", False))
+        return is_hx_spec_allowed(
+            allowed_spec,
+            hx_app,
+            view_app,
+            url_name,
+            additive,
+        )
+
     def _use_current_url(self, request):
         # Start with the current GET params
         merged_get = request.GET.copy()
